Struct mpvss_rs::DistributionSharesBox
source · [−]pub struct DistributionSharesBox {
pub commitments: Vec<BigInt>,
pub positions: BTreeMap<BigInt, i64>,
pub shares: BTreeMap<BigInt, BigInt>,
pub publickeys: Vec<BigInt>,
pub challenge: BigInt,
pub responses: BTreeMap<BigInt, BigInt>,
pub U: BigInt,
}Expand description
the dealer wishes to distribute a secret among participants P1,…,Pn. The dealer picks a randompolynomialp of degree at most t−1 with coefficients in Z_q
Fields
commitments: Vec<BigInt>positions: BTreeMap<BigInt, i64>publickeys: Vec<BigInt>challenge: BigIntresponses: BTreeMap<BigInt, BigInt>U: BigIntImplementations