Struct mpvss_rs::DistributionSharesBox [−][src]
the dealer wishes to distribute a secret among participants P1,…,Pn. The dealer picks a randompolynomialp of degree at most t−1 with coefficients in Z_q
Fields
commitments: Vec<BigInt>positions: BTreeMap<BigInt, i64>publickeys: Vec<BigInt>challenge: BigIntresponses: BTreeMap<BigInt, BigInt>U: BigIntImplementations
impl DistributionSharesBox[src]
pub fn new() -> Self[src]
pub fn init(
&mut self,
commitments: Vec<BigInt>,
positions: BTreeMap<BigInt, i64>,
shares: BTreeMap<BigInt, BigInt>,
publickeys: Vec<BigInt>,
challenge: BigInt,
responses: BTreeMap<BigInt, BigInt>,
U: BigInt
)[src]
&mut self,
commitments: Vec<BigInt>,
positions: BTreeMap<BigInt, i64>,
shares: BTreeMap<BigInt, BigInt>,
publickeys: Vec<BigInt>,
challenge: BigInt,
responses: BTreeMap<BigInt, BigInt>,
U: BigInt
)