[][src]Struct mpvss_rs::DistributionSharesBox

pub struct DistributionSharesBox {
    pub commitments: Vec<BigInt>,
    pub positions: HashMap<BigInt, i64>,
    pub shares: HashMap<BigInt, BigInt>,
    pub publickeys: Vec<BigInt>,
    pub challenge: BigInt,
    pub responses: HashMap<BigInt, BigInt>,
    pub U: BigInt,
}

the dealer wishes to distribute a secret among participants P1,...,Pn. The dealer picks a randompolynomialp of degree at most t−1 with coefficients in Z_q

Fields

commitments: Vec<BigInt>positions: HashMap<BigInt, i64>shares: HashMap<BigInt, BigInt>publickeys: Vec<BigInt>challenge: BigIntresponses: HashMap<BigInt, BigInt>U: BigInt

Implementations

impl DistributionSharesBox[src]

pub fn new() -> Self[src]

pub fn init(
    &mut self,
    commitments: Vec<BigInt>,
    positions: HashMap<BigInt, i64>,
    shares: HashMap<BigInt, BigInt>,
    publickeys: Vec<BigInt>,
    challenge: BigInt,
    responses: HashMap<BigInt, BigInt>,
    U: BigInt
)
[src]