[−][src]Struct mpvss_rs::DistributionSharesBox
the dealer wishes to distribute a secret among participants P1,...,Pn. The dealer picks a randompolynomialp of degree at most t−1 with coefficients in Z_q
Fields
commitments: Vec<BigInt>positions: HashMap<BigInt, i64>publickeys: Vec<BigInt>challenge: BigIntresponses: HashMap<BigInt, BigInt>U: BigIntImplementations
impl DistributionSharesBox[src]
pub fn new() -> Self[src]
pub fn init(
&mut self,
commitments: Vec<BigInt>,
positions: HashMap<BigInt, i64>,
shares: HashMap<BigInt, BigInt>,
publickeys: Vec<BigInt>,
challenge: BigInt,
responses: HashMap<BigInt, BigInt>,
U: BigInt
)[src]
&mut self,
commitments: Vec<BigInt>,
positions: HashMap<BigInt, i64>,
shares: HashMap<BigInt, BigInt>,
publickeys: Vec<BigInt>,
challenge: BigInt,
responses: HashMap<BigInt, BigInt>,
U: BigInt
)